@@ -1,5 +1,7 @@
 """ Apps file for setting core main registry app package when app is ready
 """
+import sys
+
 from django.apps import AppConfig
 
 from core_main_registry_app import discover
@@ -16,5 +18,6 @@ class InitApp(AppConfig):
         Returns:
 
         """
-        # Init registry
-        discover.init_registry()
+        if 'migrate' not in sys.argv:
+            # Init registry
+            discover.init_registry()
