@@ -4,6 +4,7 @@ Mongo query creation for the refinements.
 
 import logging
 import operator
+from functools import reduce
 
 from django.db.models import Q
 
@@ -47,9 +48,9 @@ def build_refinements_query(refinements):
                     # Create a dict with the dot notation as the key
                     else:
                         queries[dot_notation] = [value]
-                except (exceptions.DoesNotExist, Exception), e:
+                except (exceptions.DoesNotExist, Exception) as e:
                     logger.warning("Impossible to find the category ({0}): {1}."
-                                   .format(str(len(category_id)), e.message))
+                                   .format(str(len(category_id)), str(e)))
 
             for query in queries:
                 # Create the query with $in
@@ -68,9 +69,9 @@ def build_refinements_query(refinements):
             and_query = {'$and': or_queries}
 
         return and_query
-    except Exception, e:
+    except Exception as e:
         logger.error("Something went wrong during the creation of the refinement query. Search "
-                     "won't be refined: {0}.".format(e.message))
+                     "won't be refined: {0}.".format(str(e)))
         return {}
 
 
@@ -90,21 +91,32 @@ def get_refinement_selected_values_from_query(query):
     """
     # create a list of key (category), value_list (selected values)
     category_values_list = {}
-    # if the query have the key '$and', there is refinement selected
-    if '$and' in query:
-        for element_or in query['$and']:
-            # go through all '$or' => where refinement are
-            for element in element_or['$or']:
-                for key, value in element.iteritems():
-                    # we only want path which does not contain '#text' at the end of it
-                    if not key.endswith('#text'):
-                        for selected_value in value['$in']:
-                            # then we build our list and we don't want categories ending with '__category'
-                            if not selected_value.endswith('__category'):
-                                if key in category_values_list:
-                                    category_values_list[key].append(selected_value)
-                                else:
-                                    category_values_list.update({key: [selected_value]})
+    return_value = {}
+
+    # No "$and" means no refinement selected
+    if '$and' not in query:
+        return {}
+
+    for element_or in query['$and']:
+        if "$or" not in element_or.keys():
+            continue
+
+        # Go through all '$or' => where refinement are
+        for element in element_or['$or']:
+            for key, value in list(element.items()):
+                if key.endswith("#text"):  # Do not parse path ending with "#text"
+                    continue
+
+                for selected_value in value['$in']:
+                    # Do not parse categories ending with '__category'
+                    if selected_value.endswith('__category'):
+                        continue
+
+                    # Build category value list
+                    if key in category_values_list:
+                        category_values_list[key].append(selected_value)
+                    else:
+                        category_values_list.update({key: [selected_value]})
 
     # get global template.
     template = template_registry_api.get_current_registry_template()
@@ -113,22 +125,27 @@ def get_refinement_selected_values_from_query(query):
     refinements_ids = [x.id for x in refinements]
     # get all category.
     q_list = []
-    for key, values in category_values_list.iteritems():
+    for key, values in list(category_values_list.items()):
         # prepare the query
         q_list.append(Q(path=key) & Q(refinement_id__in=refinements_ids) & Q(value__in=values))
 
-    return_value = {}
+    if len(q_list) == 0:  # No refinement found
+        return return_value
+
     # if refinement are found, we build the structure
-    if len(q_list) > 0:
-        categories = category_api.get_all().filter((reduce(operator.or_, q_list)))
-        # now we have to build a list of {refinement name: category ids, }
-        for category in categories:
-            key = category.refinement.slug
-            display_name = category.refinement.name
-            if key in return_value:
-                return_value[key][display_name].append({"id": category.id, "value": category.value})
-            else:
-                return_value.update({key: {display_name: [{"id": category.id, "value": category.value}]}})
+    categories = category_api.get_all().filter((reduce(operator.or_, q_list)))
+    # now we have to build a list of {refinement name: category ids, }
+    for category in categories:
+        key = category.refinement.slug
+        display_name = category.refinement.name
+        if key in return_value:
+            return_value[key][display_name].append(
+                {"id": category.id, "value": category.value}
+            )
+        else:
+            return_value.update(
+                {key: {display_name: [{"id": category.id, "value": category.value}]}}
+            )
     # return the structure
     return return_value
 
