@@ -5,13 +5,13 @@ Management of the refinements' Tree from a schema.
 import logging
 from collections import OrderedDict
 
+from core_main_app.utils.xsd_flattener.xsd_flattener_database_url import XSDFlattenerDatabaseOrURL
+from core_main_registry_app.utils.refinement.tools import tree
 from core_parser_app.tools.parser.utils.xml import get_app_info_options
 from xml_utils.commons.constants import LXML_SCHEMA_NAMESPACE
 from xml_utils.xsd_tree.operations.namespaces import get_namespaces, get_target_namespace
 from xml_utils.xsd_tree.xsd_tree import XSDTree
 
-from core_main_app.utils.xsd_flattener.xsd_flattener_database_url import XSDFlattenerDatabaseOrURL
-from core_main_registry_app.utils.refinement.tools import tree
 logger = logging.getLogger("core_main_registry_app.utils.refinement.tools.xsd_refinements")
 
 
@@ -77,9 +77,9 @@ def loads_refinements_trees(template):
                                             element_display_name=element_label,
                                             enums=enums,
                                             dot_query=dot_query)
-        except Exception, e:
+        except Exception as e:
             # Log the exception
-            logger.warning(e.message)
+            logger.warning(str(e))
 
     return trees
 
@@ -93,7 +93,7 @@ def _get_flatten_schema(template):
     Returns:
 
     """
-    flatten = XSDFlattenerDatabaseOrURL(template.content.encode('utf-8'))
+    flatten = XSDFlattenerDatabaseOrURL(template.content)
     ref_xml_schema_content = flatten.get_flat()
 
     return ref_xml_schema_content
@@ -166,7 +166,7 @@ def _get_simple_type_or_complex_type_info(xml_doc_tree, target_ns_prefix, elemen
                                                  format(LXML_SCHEMA_NAMESPACE, target_ns_prefix +
                                                         element.attrib['name']))
         if len(to_search_element) == 0:
-            logger.warning("Impossible to find the element using the enumeration ({0})"
+            logger.debug("No element using the enumeration ({0})"
                            .format(str(len(element))))
             element = _find_extension(xml_doc_tree, target_ns_prefix, element)
         elif len(to_search_element) > 1:
@@ -176,9 +176,9 @@ def _get_simple_type_or_complex_type_info(xml_doc_tree, target_ns_prefix, elemen
             element = to_search_element[0]
             if query is not None:
                 query.insert(0, element.attrib['name'])
-    except Exception, e:
+    except Exception as e:
         raise Exception("Impossible to get simple type / complex type information: {0}"
-                        .format(e.message))
+                        .format(str(e)))
 
     return element
 
@@ -199,7 +199,7 @@ def _get_extension_info(xml_doc_tree, element, query=None):
                                                  format(LXML_SCHEMA_NAMESPACE,
                                                         element.attrib['base']))
         if len(to_search_element) == 0:
-            logger.warning("Impossible to find the element using the enumeration ({0})"
+            logger.debug("No element using the enumeration ({0})"
                            .format(str(len(element))))
         elif len(to_search_element) > 1:
             logger.error("More than one element using the enumeration ({0})"
@@ -208,8 +208,8 @@ def _get_extension_info(xml_doc_tree, element, query=None):
             element = to_search_element[0]
             if query is not None:
                 query.insert(0, element.attrib['name'])
-    except Exception, e:
-        raise Exception("Impossible to get the extension information: {0}".format(e.message))
+    except Exception as e:
+        raise Exception("Impossible to get the extension information: {0}".format(str(e)))
 
     return element
 
@@ -230,13 +230,13 @@ def _find_extension(xml_doc_tree, target_ns_prefix, element):
                                                  format(LXML_SCHEMA_NAMESPACE,
                                                  target_ns_prefix + element.attrib['name']))
         if len(to_search_element) == 0:
-            logger.warning("Impossible to find the enumeration ({0})".format(str(len(element))))
+            logger.debug("The enumeration ({0}) was not found".format(str(len(element))))
         elif len(to_search_element) > 1:
             logger.error("More than one enumeration using the element ({0})"
                          .format(str(len(element))))
         else:
             element = to_search_element[0]
-    except Exception, e:
-        raise Exception("Impossible to get the extension information: {0}" .format(e.message))
+    except Exception as e:
+        raise Exception("Impossible to get the extension information: {0}" .format(str(e)))
 
     return element
